# coding: utf8
"""
Reads lines from a plaintext file, separated by categories.

Category names are delimited by square brackets as the first and last
characters of the line.

Items in each category are just plain text, one item per line

Any lines before the first category will be assigned to 'uncategorized'

The format is simmilar to .ini files, only you don't have thei 'key'='value'
structure in the items.

Blank lines and lines that begin with '#' are ignored.

Example of a file:
------------------

# the following lines will be assigned to 'uncategorized`

Linux
Windows
MacOS

[Directories]
/home
/usr
/etc

# this line will be ignored

[Files]
README.md
module.py
"""


__title__ = "categorylist"
__version__ = "0.1.0"
__license__ = "GNU General Public License v2 or later (GPLv2+)"
__author__ = "Bento Loewenstein"

from .catlist import catlist



def catlist(catfile):
    """
    Returns a dictionary containing the categories and items read from
    the file passed as argument
    """
    fulldata={}
    rawfile=u''

    # Just make sure the parameters are sane
    if type(catfile) is not str:
        raise TypeError('File name must be a string')
    if type(catfile) is str and len(catfile)==0:
        raise ValueError('File name can not be empty')

    # Open file read-only and reads all lines
    try:
        with open(catfile,'r') as _file:
            rawfile = _file.readlines()
    except OSError:
        print("Could not open file {}".format(catfile), file=sys.stderr)
        raise

    # just in case someone tries to read a file without any valid category
    # or with lines before the first true category, puts the lines on a
    # default category
    cur_category='uncategorized'
    for lin in rawfile:
        # let's skip blank line. first strip all spaces, left and right
        lin=lin.rstrip().lstrip()
        # decide what to do. If a category line is well formed, create it, otherwise
        # add the line to an existing one
        if len(lin)==0 or lin[0]=='#': continue
        if lin[0]=='[' and lin[-1]==']':
            cur_category=lin[1:-1]
            # what happens if the category already exists ?
            if not fulldata.get(cur_category):
                fulldata[cur_category]=[]
        else:
            if not fulldata.get(cur_category):
                fulldata[cur_category]=[lin]
            else:
                fulldata[cur_category].append(lin)

    return fulldata



import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="simple-categories",
    version="0.1.1",
    description="Reads a categorized file and returns a dictionary",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/Nerdeiro/category-lists",
    author="Bento Loewenstein Silveira",
    author_email="anarch157a@ninjazumbi.com",
    license="GPL2",
    classifiers=[
        "License :: OSI Approved :: GNU General Public License v2 or later (GPLv2+)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
    ],
    packages=["catlist"],
    include_package_data=True
)
